#ifndef ROOT_MyAnalysisEvent
#define ROOT_MyAnalysisEvent

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// MyAnalysisEvent                                                                //
//                                                                      //
// A CLEO DST Event tree                                                //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

#include "TObject.h"
#include "TClonesArray.h"
#include "TRefArray.h"
#include "TRef.h"
#include "TH1.h"
#include "TMath.h"
#include "TString.h"
#include "DTagVVProc/MyEvent.h"
//#include "DTagVVProc/MyParticle.h"
//#include "DTagVVProc/MyTrack.h"
//#include "DTagVVProc/MyShower.h"
//#include "DTagVVProc/MyPion.h"
//#include "DTagVVProc/MyPi0.h"
//#include "DTagVVProc/MyKaon.h"
//#include "DTagVVProc/MyPhoton.h"
#include "DTagVVProc/MyPhi.h"
#include "DTagVVProc/MyRho0.h"
//#include "DTagVVProc/MyDTag.h"
#include "DTagVVProc/MyDPhiGamma.h"
#include "DTagVVProc/MyDPhiRho0.h"
#include "DTagVVProc/MyDTagDPhiRho0.h"


class TDirectory;

//class MyParticle;
//class MyTrack;
//class MyShower;
//class MyPion;
//class MyPi0;
//class MyKaon;
//class MyPhoton;
class MyEvent;
class MyPhi;
class MyRho0;
//class MyDTag;
class MyDPhiGamma;
class MyDPhiRho0;
class MyDTagDPhiRho0;
 
 
 

class MyAnalysisEvent : public MyEvent {
  
 private:
  
  int NDPhiGamma;  // Number of Signal DPhiGammas
  TClonesArray  *fMyDPhiGammas;   //->array with all signal DPhiGammas
  //  TRef fLastMyDPhiGamma;         //reference pointer to last DPhiGamma
  //  static TClonesArray *fgMyDPhiGammas;
  
  int NDPhiRho0;  // Number of Signal DPhiRho0s
  TClonesArray  *fMyDPhiRho0s;   //->array with all signal DPhiRho0s
  //  TRef fLastMyDPhiRho0;         //reference pointer to last DPhiRho0
  //  static TClonesArray *fgMyDPhiRho0s;
  
  int NDTagDPhiRho0;  // Number of DTagDPhiRho0s
  TClonesArray  *fMyDTagDPhiRho0s;   //->array with all signal DTagDPhiRho0s
  //  TRef fLastMyDTagDPhiRho0;         //reference pointer to last DPhiRho0
  //  static TClonesArray *fgMyDTagDPhiRho0s;
  
  int NPhi;  // Number of Phis
  TClonesArray  *fMyPhis;    //->array with all phis
  //  TRef fLastMyPhi;         //reference pointer to last phi
  //  static TClonesArray *fgMyPhis;
  
  int NRho0;  // Number of Rho0s
  TClonesArray  *fMyRho0s;    //->array with all rho0s
  //  TRef fLastMyRho0;         //reference pointer to last rho0
  //  static TClonesArray *fgMyRho0s;
  

 public:
  
  MyAnalysisEvent();
  virtual ~MyAnalysisEvent();
  void          Clear(Option_t *option ="");
  //  static void   Reset(Option_t *option ="");



  MyDPhiGamma* AddDPhiGamma();
  int  GetNDPhiGamma() { return NDPhiGamma; }
  Int_t FillMyDPhiGammaList();
  TClonesArray *GetDPhiGammas() const {return fMyDPhiGammas;}
  //  MyDPhiGamma  *GetLastDPhiGamma() const {return (MyDPhiGamma*)fLastMyDPhiGamma.GetObject();}

  MyDPhiRho0* AddDPhiRho0();
  int  GetNDPhiRho0() { return NDPhiRho0; }
  Int_t FillMyDPhiRho0List();
  TClonesArray *GetDPhiRho0s() const {return fMyDPhiRho0s;}
  //  MyDPhiRho0  *GetLastDPhiRho0() const {return (MyDPhiRho0*)fLastMyDPhiRho0.GetObject();}

  MyDTagDPhiRho0* AddDTagDPhiRho0();
  int  GetNDTagDPhiRho0() { return NDTagDPhiRho0; }
  Int_t FillMyDTagDPhiRho0List();
  TClonesArray *GetDTagDPhiRho0s() const {return fMyDTagDPhiRho0s;}
  //  MyDTagDPhiRho0  *GetLastDTagDPhiRho0() const {return (MyDTagDPhiRho0*)fLastMyDTagDPhiRho0.GetObject();}

  int  GetNPhi() { return NPhi; }
  MyPhi* AddPhi();
  TClonesArray *GetPhis() const {return fMyPhis;}
  //  MyPhi  *GetLastPhi() const {return (MyPhi*)fLastMyPhi.GetObject();}
  int FillMyPhiList();
  bool IsOtherSidePhi(MyDTag* dtag, MyPhi* phi);

  int  GetNRho0() { return NRho0; }
  MyRho0* AddRho0();
  TClonesArray *GetRho0s() const {return fMyRho0s;}
  //  MyRho0  *GetLastRho0() const {return (MyRho0*)fLastMyRho0.GetObject();}
  int FillMyRho0List();
  bool IsOtherSideRho0(MyDTag* dtag, MyRho0* rho0);




  ClassDef(MyAnalysisEvent,99)  //MyAnalysisEvent structure
};


#endif
