#ifndef ROOT_MyEvent
#define ROOT_MyEvent

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// MyEvent                                                                //
//                                                                      //
// A CLEO DST Event tree                                                //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

#include "TObject.h"
#include "TClonesArray.h"
#include "TRefArray.h"
#include "TRef.h"
#include "TH1.h"
#include "TMath.h"
#include "TString.h"
#include "DTagVVProc/MyMCParticle.h"
#include "DTagVVProc/MyParticle.h"
#include "DTagVVProc/MyTrack.h"
#include "DTagVVProc/MyShower.h"
#include "DTagVVProc/MyPion.h"
#include "DTagVVProc/MyPi0.h"
#include "DTagVVProc/MyKaon.h"
#include "DTagVVProc/MyPhoton.h"
#include "DTagVVProc/MyDTag.h"


class TDirectory;

class MyParticle;
class MyTrack;
class MyShower;
class MyPion;
class MyPi0;
class MyKaon;
class MyPhoton;
class MyDTag;
class MyMCParticle;
//class MyMCVertex;
 
 
 

class MyEvent : public TObject {

 private:

  int Run;
  int Event;
  float BeamEnergy;

  int NTrk;  // Number of Tracks
  TClonesArray  *fMyTracks;            //->array with all tracks
  //  TRef fLastMyTrack;         //reference pointer to last track
  // static TClonesArray *fgMyTracks;

  int NShwr;  // Number of showers
  TClonesArray  *fMyShowers;  //->array with all showers
  //  TRef fLastMyShower;         //reference pointer to last shower
  // static TClonesArray *fgMyShowers;

  
  int NDTag;  // Number of DTags
  TClonesArray  *fMyDTags;            //->array with all dtags
  //  TRef fLastMyDTag;         //reference pointer to last dtag
  // static TClonesArray *fgMyDTags;
    
  int NPion;  // Number of Pions
  TClonesArray  *fMyPions;    //->array with all pions
  //  TRef fLastMyPion;         //reference pointer to last pion
  // static TClonesArray *fgMyPions;
    
  int NPi0;  // Number of Pi0s
  TClonesArray  *fMyPi0s;    //->array with all pi0s
  //  TRef fLastMyPi0;         //reference pointer to last pi0
  // static TClonesArray *fgMyPi0s;
  

  int NKaon;  // Number of Kaons
  TClonesArray  *fMyKaons;    //->array with all kaons
  //  TRef fLastMyKaon;         //reference pointer to last kaon
  // static TClonesArray *fgMyKaons;

  
  int NPhoton;  // Number of Photons
  TClonesArray  *fMyPhotons;    //->array with all photons
  //  TRef fLastMyPhoton;         //reference pointer to last photon
  // static TClonesArray *fgMyPhotons;

  
  int NMCParticle;  // Number of MC Particles
  TClonesArray  *fMyMCParticles;    //->array with all MC Particles
  //  TRef fLastMyMCParticle;         //reference pointer to last MC Particle
  // static TClonesArray *fgMyMCParticles;

  
 public:

  MyEvent();
  virtual ~MyEvent();
  void          Clear(Option_t *option ="");
  //  static void   Reset(Option_t *option ="");
  void  SetRun(int n) { Run = n; }
  void  SetEvent(int n) { Event = n; }
  void  SetBeamEnergy(float n ) { BeamEnergy = n;} 
  MyTrack* AddTrack();
  MyShower* AddShower();
  MyDTag* AddDTag();
  MyPion* AddPion();
  MyPi0* AddPi0();
  MyKaon* AddKaon();
  MyPhoton* AddPhoton();
  MyMCParticle* AddMCParticle();

  int  GetRun() { return Run; }
  int  GetEvent() { return Event; }
  float GetBeamEnergy( ) { return BeamEnergy;} 
  int  GetNTrk() { return NTrk; }
  int  GetNShwr() { return NShwr; }
  int  GetNPion() { return NPion; }
  int  GetNPi0() { return NPi0; }
  int  GetNKaon() { return NKaon; }
  int  GetNPhoton() { return NPhoton; }
  int  GetNDTag() { return NDTag; }
  int  GetNMCParticle() { return NMCParticle; }


  TClonesArray *GetTracks() const {return fMyTracks;}
  //  MyTrack  *GetLastTrack() const {return (MyTrack*)fLastMyTrack.GetObject();}

  TClonesArray *GetShowers() const {return fMyShowers;}
  //  MyShower  *GetLastShower() const {return (MyShower*)fLastMyShower.GetObject();}

  TClonesArray *GetPions() const {return fMyPions;}
  //  MyPion  *GetLastPion() const {return (MyPion*)fLastMyPion.GetObject();}

  TClonesArray *GetPi0s() const {return fMyPi0s;}
  //  MyPi0  *GetLastPi0() const {return (MyPi0*)fLastMyPi0.GetObject();}

  TClonesArray *GetKaons() const {return fMyKaons;}
  //  MyKaon  *GetLastKaon() const {return (MyKaon*)fLastMyKaon.GetObject();}

  TClonesArray *GetPhotons() const {return fMyPhotons;}
  //  MyPhoton  *GetLastPhoton() const {return (MyPhoton*)fLastMyPhoton.GetObject();}

  TClonesArray *GetDTags() const {return fMyDTags;}
  //  MyDTag  *GetLastDTag() const {return (MyDTag*)fLastMyDTag.GetObject();}

  TClonesArray *GetMCParticles() const {return fMyMCParticles;}
  //  MyMCParticle  *GetLastMCParticle() const {return (MyMCParticle*)fLastMyMCParticle.GetObject();}


  ClassDef(MyEvent,99)  // MyEvent data structure (basic detected objects)
};


#endif
